#ifndef func_h
#define func_h

#include <stdio.h>

#define MAXCOLUM 80
#define MAXFILAS 25
#define MAXENT 30
#define MAXAST 2000

FILE *LeerNomFic (char *modo);
int *DatoArchivo(FILE *pfic);
int AnaDatos(int *);
int BuscaFigura (int *,int *,int *,int *,int *);
int *alrededor (int,int,int*);
int miralinea(int,int,int,int*,int*,int*);
int buscauno (int i,int *pAster,int *phayuno,int *pNumAlred);
int existen(int *,int*);
int existeuno(int,int *,int *);
int guardar(int *,int );
int FigCerrada (int *);
int FigBifurc (int *);
char *DetectaFigura (int,int);
int ImpResult (char *);

/***********************************************************************
	FILE *LeerNomFic(char *modo);
		PREGUNTA NOMBRE DE FICHERO Y LO ABRE

	Descripcion: Se pregunta el nombre del fichero y se intenta abrir
				segun el modo indicado. En caso de no  poderse abrir
				se enva un mensaje de error a la pantalla

	Argumentos: char *modo: El modo sigue las reglas de fopen
				ejemplo "r" para lectura, "w" escritura

	Devuelve: Puntero al fichero abierto o NULL si no se ha podido
***********************************************************************/

/*************************************************************************
    int *DatoArchivo(FILE *pfic);
		GENERA EL PUNTERO CON LAS POSICIONES DE LOS ASTERISCOS

	Descripcion: recibe el fichero, lee secuencialmente y va almacenando
                 las posiciones donde encuentra asteriscos. El fichero
                 debe tener 25 filas por 80 columnas. La reserva de
                 memoria del vector donde se almacenan las posiciones
                 se realiza de forma dinamica.

	Argumentos: FILE *, el fichero donde se encuentran las figuras

	Devuelve:   vector donde se almacenan las posiciones.
*************************************************************************/

/*************************************************************************
    int *AnaDatos(int *);
		ANALIZA EL PUNTERO CON LAS POSICIONES DE LOS ASTERISCOS

	Descripcion: recibe el puntero con las posiciones, analiza por separado
                 cada figura, la identifica, elimina las posiciones de
                 los asteriscos de esta figura y actualiza el vector
                 dirigiendose a la figura siguiente. Gestiona el vector
                 con los resultados.

	Argumentos: int *, el vector donde se encuentran las posiciones de los
                asteriscos.

	Devuelve:   vector donde se registran los resultados.
*************************************************************************/

/*************************************************************************
    int BuscaFigura (int *,int *,int *,int *,int *)
		RECONOCE UNA FIGURA PARTIENDO DEL VECTOR DE LOS ASTERISCOS

	Descripcion: recibe posiciones del asterisco anterior y actual 
                 para buscar asteriscos nuevos alrededor de este ultimo.
                 Actualiza vectores utilizados para una nueva busqueda,
                 hasta que no encuentre ninguno nuevo.

	Argumentos:  posicion asterisco actual.
  (todos int *)  posicion asterisco anterior.
                 vector posiciones asteriscos reconocidos en figura.
                 vector posiciones asteriscos inicio bifurcacion.
                 vector posiciones asteriscos leidos desde fichero.
                                                                 
	Devuelve:   nada directamente, pasa parametros por referencia. 
*************************************************************************/

/*************************************************************************
    int *alrededor (int,int,int*)
		ENCUENTRA ASTERISCOS ALREDEDOR DEL ACTUAL

	Descripcion: recibe posiciones del asterisco anterior y actual 
                 para buscar asteriscos alrededor de este ultimo. Ordena
                 los numeros encontrados (2 como mucho) de menor a mayor.
                 No se tiene en cuenta el asterisco del cual se proceda 
                 para contabilizar los de alrededor.

	Argumentos:  posicion asterisco anterior.
                 posicion asterisco actual.
                 vector posiciones asteriscos leidos desde fichero.
                                                                 
	Devuelve:   vector posiciones asteriscos de alrededor. 
*************************************************************************/

/*************************************************************************
    int miralinea(int,int,int,int*,int*,int*)
		ENCUENTRA ASTERISCOS EN LINEA ACTUAL

	Descripcion: recibe posiciones del asterisco anterior y actual, y de
                 la fila respecto asterisco actual.  
                 Busca asteriscos diferentes del anterior y del actual.

	Argumentos:  posicion asterisco actual.
                 posicion fila respecto asterisco actual (+80,0,-80).
                 posicion asterisco anterior.
                 indicador de que ha encontrado 1 (no pueden ser >2).
                 vector posiciones asteriscos encontrados alrededor.
                 vector posiciones asteriscos leidos desde fichero.
                                                                 
	Devuelve:   cero, aunque pasa parametros por referencia. 
*************************************************************************/

/*************************************************************************
    int buscauno (int,int *,int *,int *)
		BUSCA ASTERISCO EN VECTOR DE POSICIONES

	Descripcion: recibe posicion del asterisco y lo busca en el vector
                 de posiciones de los asteriscos leidos desde fichero.
                 Comprueba si es el primero o el segundo que se
                 encuentra.

	Argumentos:  posicion asterisco actual.
                 vector posiciones asteriscos leidos desde fichero.
                 indicador de que ha encontrado 1 (no pueden ser >2).
                 vector posiciones asteriscos encontrados alrededor.
                 
                                                                 
	Devuelve:   cero, aunque pasa parametros por referencia. 
*************************************************************************/

/*************************************************************************
    int existen(int *,int *)
         COMPRUEBA SI ASTERISCOS ESTAN REGISTRADOS YA

	Descripcion: recibe un vector con las posiciones de los asteriscos
                 encontrados y dictamina si hay alguno que ya pertenece
                 a la figura.

	Argumentos: vector posiciones asteriscos encontrados alrededor.
                vector posiciones asteriscos reconocidos de la figura.

	Devuelve:   1 si ha encontrado alguno todavia no registrado.
*************************************************************************/

/*************************************************************************
    int existeuno(int,int *,int *)
         COMPRUEBA SI ASTERISCO ESTA REGISTRADO YA

	Descripcion: recibe la posicion de un asterisco encontrado y 
                 dictamina si ya pertenece a la figura. Se exceptua el
                 primero para que en figuras circulares se pueda 
                 comprobar que efectivamente se vuelve a el.

	Argumentos: posicion asterisco encontrado alrededor.
                vector posiciones asteriscos reconocidos de la figura.
                puntero a la variable que indica el exito de busqueda.
                       
	Devuelve:   nada.
*************************************************************************/

/*************************************************************************
    int guardar(int *,int )
        GUARDA EL DATO EN EL VECTOR APROPIADO

	Descripcion:  recibe un dato que es guardado en la primera posicion
                  libre encontrada en el vector, que es actualizado. La 
                  posicion libre es un cero (0). 

	Argumentos:   variable entera que se va a guardar.
                  vector de enteros donde se va a guardar el dato.

	Devuelve:     nada, paso de vector por referencia.
*************************************************************************/

/*************************************************************************
    int FigCerrada (int *)
        DICTAMINA SI LA FIGURA ES ABIERTA O CERRADA

	Descripcion:  examina el vector de posiciones de los asteriscos
                  registrados de la figura para saber si se repite el
                  primer asterisco encontrado.

	Argumentos:   vector posiciones asteriscos reconocidos de la figura

	Devuelve:     1 si la figura es cerrada.
*************************************************************************/

/*************************************************************************
    int FigBifurc (int *)
        DICTAMINA SI LA FIGURA TIENE BIFURCACIONES

	Descripcion:  examina el vector de posiciones de los asteriscos
                  en los que empiezan bifurcaciones para saber cuantos
                  se encuentran. Segun como se han definido las
                  bifurcaciones, el cilindro presenta 3 y las figuras
                  cerradas y en forma de 't' tienen 1.

	Argumentos:   vector posiciones asteriscos bifurcaciones.

	Devuelve:     1 si la figura es un cilindro.
*************************************************************************/

/*************************************************************************
    char *DetectaFigura (int,int)
        DEFINE QUE TIPO DE FIGURA SE HA ENCONTRADO

	Descripcion:  sabiendo si la figura es abierta o no, despues 
                  identifica entre cilindros y formas cerradas.
              
	Argumentos:   variable que indica si es un cilindro.
                  variable que indica si la figura es cerrada.

	Devuelve:     array con el tipo de figura encontrado.
*************************************************************************/


/*************************************************************************
    int ImpResult(char *);
         ESCRIBE LOS RESULTADOS EN UN FICHERO

	Descripcion: recibe un array con la forma encontrada, pide un nombre 
                 para el fichero donde escribirlo y lo escribe, ademas
                 de sacarlo por pantalla.

	Argumentos: char *, el puntero con el tipo de forma.

	Devuelve:   nada.
*************************************************************************/

#endif
